==> antd-mobile-0.9.14.tgz: package/lib/progress/demo/basic.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _whiteSpace=require('antd-mobile/components/white-space');var _whiteSpace2=_interopRequireDefault(_whiteSpace);var _button=require('antd-mobile/components/button');var _button2=_interopRequireDefault(_button);var _progress=require('antd-mobile/components/progress');var _progress2=_interopRequireDefault(_progress);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);var _react=require('react');var _react2=_interopRequireDefault(_react);
var _reactNative=require('react-native');function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}var

BasicProgressExample=function(_React$Component){(0,_inherits3["default"])(BasicProgressExample,_React$Component);
function BasicProgressExample(props){(0,_classCallCheck3["default"])(this,BasicProgressExample);var _this=(0,_possibleConstructorReturn3["default"])(this,
_React$Component.call(this,props));
_this.onAdd=function(){
var p=_this.state.percent+10;
if(_this.state.percent>=100){
p=0;
}
_this.setState({percent:p});
};
_this.state={
percent:40};return _this;

}BasicProgressExample.prototype.
render=function render(){
return _react2["default"].createElement(_reactNative.View,null,
_react2["default"].createElement(_progress2["default"],{percent:90,position:"fixed"}),
_react2["default"].createElement(_reactNative.View,{style:{
marginTop:80,
flexDirection:'row',justifyContent:'space-between',alignItems:'center'}},

_react2["default"].createElement(_reactNative.View,{style:{marginRight:10,height:4,flex:1}},
_react2["default"].createElement(_progress2["default"],{percent:this.state.percent})),

_react2["default"].createElement(_reactNative.Text,null,
this.state.percent,
"%")),
_react2["default"].createElement(_button2["default"],{style:{width:50,marginLeft:10},type:"ghost",size:"small",onClick:this.onAdd},"(+-)10"),
_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_progress2["default"],{percent:5}));
};return BasicProgressExample;}(_react2["default"].Component);exports["default"]=BasicProgressExample;module.exports=exports['default'];

==> antd-mobile-1.0.1.tgz: package/lib/progress/demo/basic.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _whiteSpace=require('antd-mobile/components/white-space');var _whiteSpace2=_interopRequireDefault(_whiteSpace);var _button=require('antd-mobile/components/button');var _button2=_interopRequireDefault(_button);var _progress=require('antd-mobile/components/progress');var _progress2=_interopRequireDefault(_progress);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);var _react=require('react');var _react2=_interopRequireDefault(_react);
var _reactNative=require('react-native');function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}var

BasicProgressExample=function(_React$Component){(0,_inherits3["default"])(BasicProgressExample,_React$Component);
function BasicProgressExample(props){(0,_classCallCheck3["default"])(this,BasicProgressExample);var _this=(0,_possibleConstructorReturn3["default"])(this,
_React$Component.call(this,props));
_this.onAdd=function(){
var p=_this.state.percent+10;
if(_this.state.percent>=100){
p=0;
}
_this.setState({percent:p});
};
_this.state={
percent:40};return _this;

}BasicProgressExample.prototype.
render=function render(){
var viewStyle={
marginTop:80,
flexDirection:'row',justifyContent:'space-between',alignItems:'center'};

return _react2["default"].createElement(_reactNative.View,null,
_react2["default"].createElement(_progress2["default"],{percent:90,position:'fixed'}),

_react2["default"].createElement(_reactNative.View,{style:[viewStyle]},
_react2["default"].createElement(_reactNative.View,{style:{marginRight:10,height:4,flex:1}},_react2["default"].createElement(_progress2["default"],{percent:this.state.percent})),
_react2["default"].createElement(_reactNative.Text,null,this.state.percent,'%')),

_react2["default"].createElement(_button2["default"],{style:{width:50,marginLeft:10},type:'ghost',size:'small',onClick:this.onAdd},'(+-)10'),

_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_progress2["default"],{percent:5}));


};return BasicProgressExample;}(_react2["default"].Component);exports["default"]=BasicProgressExample;module.exports=exports['default'];
